.. fwdpy11 documentation master file, created by
   sphinx-quickstart on Mon Mar 20 12:22:19 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to fwdpy11's documentation!
===================================

.. toctree::
    :caption: Contents:

.. toctree::
    :caption: Miscellaneous notes
    :maxdepth: 1

    pages/conventions
    pages/changelog
    pages/upgrade_path
    pages/deprecated
    pages/todo
    pages/pubs
    pages/developers

.. toctree::
    :caption: Concepts
    :maxdepth: 2

    pages/definitions

.. toctree::
    :caption: Data Types
    :maxdepth: 2

    pages/types
    pages/rng
    pages/regions
    pages/geneticvalues
    pages/fixations
    pages/model_params
    pages/recorders
    pages/pickling
    pages/binary

.. toctree::
    :caption: Tree sequence recording
    :maxdepth: 2

    pages/tsoverview
    pages/tstypes
    pages/ts
    pages/tsdetails

.. toctree::
    :caption: Examples
    :maxdepth: 1

    examples/processingpops
    examples/sampling
    examples/parallel_simulation
    examples/customgvalue
    examples/stateful_fitness
    examples/DataMatrix
    examples/qtrait
    examples/parentage

.. toctree::
    :caption: Advanced manipulation of populations
    :maxdepth: 2

    pages/popobjects
    pages/manip_mutations

.. toctree::
    :caption: Maximizing performance
    :maxdepth: 1

    performance/optimization
    performance/processingpops_np

.. toctree::
    :caption: Advanced topics and examples
    :maxdepth: 1

    advanced/heritability
    advanced/manip


.. toctree::
    :caption: Modules
    :maxdepth: 2

fwdpy11
------------------------------
.. automodule:: fwdpy11
    :members:
    :inherited-members:
    :imported-members:
    :show-inheritance:

fwdpy11._Population
------------------------------
.. automodule:: fwdpy11._Population
    :members:
    :show-inheritance:

fwdpy11._Populations
------------------------------
.. automodule:: fwdpy11._Populations
    :members:
    :show-inheritance:

fwdpy11.ts
------------------------------
.. automodule:: fwdpy11.ts
    :members:
    :show-inheritance:

fwdpy11.tsrecorders
------------------------------
.. automodule:: fwdpy11.tsrecorders
    :members:
    :show-inheritance:

fwdpy11.ts_from_msprime
------------------------------
.. automodule:: fwdpy11.ts_from_msprime
    :members:
    :show-inheritance:

fwdpy11.genetic_values
------------------------------
.. automodule:: fwdpy11.genetic_values
    :members:
    :show-inheritance:
    :special-members:

fwdpy11.genetic_value_noise
------------------------------
.. automodule:: fwdpy11.genetic_value_noise
    :members:
    :show-inheritance:
    :special-members:

fwdpy11.sampling
------------------------------
.. automodule:: fwdpy11.sampling
    :members:
    :show-inheritance:

fwdpy11.model_params
------------------------------
.. automodule:: fwdpy11.model_params
    :members:
    :show-inheritance:

fwdpy11.temporal_samplers
------------------------------
.. automodule:: fwdpy11.temporal_samplers
    :members:
    :show-inheritance:

fwdpy11.wright_fisher
------------------------------
.. automodule:: fwdpy11.wright_fisher
    :members:
    :show-inheritance:

fwdpy11.wright_fisher_ts
------------------------------
.. automodule:: fwdpy11.wright_fisher_ts
    :members:
    :show-inheritance:

fwdpy11.multilocus
------------------------------
.. automodule:: fwdpy11.multilocus
    :members:
    :show-inheritance:

fwdpy11.util
------------------------------
.. automodule:: fwdpy11.util
    :members:
    :show-inheritance:

fwdpy11.demography
------------------------------------------------------------
.. automodule:: fwdpy11.demography
    :members:
    :show-inheritance:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
